@@ -23,4 +23,9 @@ from .offline_feature import OfflineFeature
 from .online_feature import OnlineFeature
 from .plp import OnlinePlp, Plp
 from .spectrogram import Spectrogram
-__version__ = '1.17'
+
+from pathlib import Path as _Path
+
+cmake_prefix_path = _Path(__file__).parent / "share" / "cmake"
+del _Path
+__version__ = '1.19.1'
